@@ -1,12 +1,11 @@
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from logging.handlers import RotatingFileHandler
 import logging
-import sys
 import os
 loggingConstants = LoggingConstants()
 class CreateLoggerController:
     def __init__(self, loggername):
-        self.currentpath = os.path.dirname(os.path.realpath(__file__))
+        self.currentpath = str(os.path.dirname(os.path.realpath(__file__)))
         self.logger = logging.getLogger(loggername)
         self.logger.propagate = True
         log_format = logging.Formatter(loggingConstants.LOGFORMAT)
