@@ -21,4 +21,15 @@ class SSLSocketController(MainSocketController):
                                         self.MainSocket.sockProto)
         self.MainSocket.sock.bind((self.MainSocket.ip, self.MainSocket.port))
         self.MainSocket.sock = context.wrap_socket(self.MainSocket.sock, server_side=True)
+        return self.MainSocket.sock
+
+    def createClientSocket(self, serverIP):
+        context = ssl.SSLContext()
+        context.load_verify_locations(cafile=self.MainSocket.CA)
+        context.load_cert_chain(certfile=self.MainSocket.pemDir, keyfile=self.MainSocket.keyDir,
+                                password=self.MainSocket.password, )
+        context.verify_mode = ssl.CERT_OPTIONAL
+        context.check_hostname = False
+        self.MainSocket.sock = socket.socket(self.MainSocket.socketAF, self.MainSocket.socketSTREAM)
+        self.MainSocket.sock = context.wrap_socket(self.MainSocket.sock)
         return self.MainSocket.sock
\ No newline at end of file
