@@ -3,12 +3,13 @@ from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingCons
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 from FreeTAKServer.model.FTSModel.Event import Event as event
 from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
-
+from abc import ABC
+from FreeTAKServer.controllers.serializers import xml_serializer
 
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendCoTAbstract").getLogger()
 
-class SendCoTAbstractController:
+class SendCoTAbstractController(ABC):
     Event = event
     def __init__(self, object):
         pass
@@ -50,7 +51,7 @@ class SendCoTAbstractController:
         """
         from FreeTAKServer.controllers.XMLCoTController import XMLCoTController
 
-        modelInstance = XMLCoTController().serialize_CoT_to_model(tempObject, etree.fromstring(xmlString))
+        modelInstance = xml_serializer.XmlSerializer().from_format_to_fts_object(xmlString, tempObject)
         return modelInstance
     def create_xml_string(self, modelObject):
         """
